@@ -8,7 +8,7 @@
  *  See also https://www.freebsd.org/copyright/freebsd-license.html
  *  --------
  *
- *  Copyright (C) 2009-2024 Erwin Waterlander
+ *  Copyright (C) 2009-2025 Erwin Waterlander
  *  Copyright (C) 1994-1995 Benjamin Lin.
  *  All rights reserved.
  *
@@ -69,7 +69,7 @@ void PrintLicense(void)
   D2U_ANSI_FPRINTF(stdout,_("\
 Copyright (C) 2009-%d Erwin Waterlander\n\
 Copyright (C) 1994-1995 Benjamin Lin\n\
-All rights reserved.\n\n"),2024);
+All rights reserved.\n\n"),2025);
   PrintBSDLicense();
 }
 
@@ -158,7 +158,7 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *prog
             RetVal = -1;
             ipFlag->status |= BINARY_FILE ;
             if (ipFlag->verbose) {
-              if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
+              ipFlag->error = 1;
               D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
               D2U_UTF8_FPRINTF(stderr, _("Binary symbol 0x00%02X found at line %u\n"), TempChar, line_nr);
             }
@@ -229,7 +229,7 @@ int ConvertUnixToDosW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *prog
             RetVal = -1;
             ipFlag->status |= BINARY_FILE ;
             if (ipFlag->verbose) {
-              if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
+              ipFlag->error = 1;
               D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
               D2U_UTF8_FPRINTF(stderr, _("Binary symbol 0x00%02X found at line %u\n"), TempChar, line_nr);
             }
@@ -380,7 +380,7 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
             RetVal = -1;
             ipFlag->status |= BINARY_FILE ;
             if (ipFlag->verbose) {
-              if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
+              ipFlag->error = 1;
               D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
               D2U_UTF8_FPRINTF(stderr, _("Binary symbol 0x%02X found at line %u\n"), TempChar, line_nr);
             }
@@ -451,7 +451,7 @@ int ConvertUnixToDos(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
             RetVal = -1;
             ipFlag->status |= BINARY_FILE ;
             if (ipFlag->verbose) {
-              if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
+              ipFlag->error = 1;
               D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
               D2U_UTF8_FPRINTF(stderr, _("Binary symbol 0x%02X found at line %u\n"), TempChar, line_nr);
             }
